==> core_models-0.0.1.gem: app/models/core_models/base/currency.rb <==
# encoding: utf-8

# TODO: Check out some currency exchange rate implementations.
# eu_central_bank
# google_currency

#require 'action_view/helpers/number_helper'

module CoreModels
  class Base::Currency < ActiveRecord::Base

    attr_accessible :date_of_rate, :is_active, :iso_code, :name, :rate, :surcharge, :symbol, :symbol_as_prefix

    validates :iso_code, :presence => true
    validates :name, :presence => true

    #----------------------------------------------------------------------------

    def to_s
      iso_code_with_name
    end

    def iso_code_with_name
      "#{iso_code} (#{name})"
    end

    def as_string(amount)
      unit = self.symbol.nil? ? self.iso_code : self.symbol
      format = self.symbol_as_prefix ? "%u%n" : "%n%u"
      ActionController::Base.helpers.number_to_currency(amount, {:unit => unit, :format => format})
    end

    def as_iso_string(amount)
      unit = self.iso_code
      format = "%u %n"
      ActionController::Base.helpers.number_to_currency(amount, {:unit => unit, :format => format})
    end

    def self.default
      ::CoreModels::Base::Currency.find_by_iso_code('GBP')
    end

    def self.as_string(amount, currency = nil)
      currency = ::CoreModels::Base::Currency.default if currency.nil?
      currency.as_string(amount)
    end

    def self.as_iso_string(amount, currency = nil)
      currency = ::CoreModels::Base::Currency.default if currency.nil?
      currency.as_iso_string(amount)
    end

    def coversion_rate_to(currency)
      currency.rate / self.rate
    end

  end
end

==> core_models-0.1.0.gem: app/models/core_models/base/currency.rb <==
# encoding: utf-8

# TODO: Check out some currency exchange rate implementations.
# eu_central_bank
# google_currency

#require 'action_view/helpers/number_helper'

module CoreModels
  class Base::Currency < ActiveRecord::Base

    #attr_accessible :date_of_rate, :is_active, :iso_code, :name, :rate, :surcharge, :symbol, :symbol_as_prefix

    validates :iso_code, :presence => true
    validates :name, :presence => true

    #----------------------------------------------------------------------------

    def to_s
      iso_code_with_name
    end

    def iso_code_with_name
      "#{iso_code} (#{name})"
    end

    def as_string(amount)
      unit = self.symbol.nil? ? self.iso_code : self.symbol
      format = self.symbol_as_prefix ? "%u%n" : "%n%u"
      ActionController::Base.helpers.number_to_currency(amount, {:unit => unit, :format => format})
    end

    def as_iso_string(amount)
      unit = self.iso_code
      format = "%u %n"
      ActionController::Base.helpers.number_to_currency(amount, {:unit => unit, :format => format})
    end

    def self.default
      ::CoreModels::Base::Currency.find_by_iso_code('GBP')
    end

    def self.as_string(amount, currency = nil)
      currency = ::CoreModels::Base::Currency.default if currency.nil?
      currency.as_string(amount)
    end

    def self.as_iso_string(amount, currency = nil)
      currency = ::CoreModels::Base::Currency.default if currency.nil?
      currency.as_iso_string(amount)
    end

    def coversion_rate_to(currency)
      currency.rate / self.rate
    end

  end
end
